unit ExcelGrid;

interface

uses
  Windows, SysUtils, Classes, Graphics, Forms, DDEMan, DB, DBGrids;

type
  EExcelDDE = class(Exception);

  TCustomExcelDDE = class(TComponent)
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
    procedure Open;
    procedure Close;
    procedure FindServerApplication; virtual;
    procedure Execute(const Command : string);
    function Request(const Item : string) : string;
    property OnConnect : TNotifyEvent;
    property OnDisconnect : TNotifyEvent;
    property ServerName : string;
    property DDEConv : TDDEClientConv;
    property Active : Boolean;
    property Ready : Boolean;
  end;

  TExcelDDE = class(TCustomExcelDDE)
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
    procedure NewTable; 
    procedure CloseTable;
    procedure Print;
    procedure SaveAs(const FileName : string);
    procedure Save;
    procedure Load(const FileName : string);
    procedure Minimize;
    procedure Restore;
    procedure DisableControls;
    procedure EnableControls;
    procedure DisableInput;
    procedure EnableInput;
    property Cells[Row, Col : integer] : TExcelCell;
    property Rows[Row : integer] : TExcelRow;
    property Columns[Col : integer] : TExcelColumn;
    property Selection[R1, C1, R2, C2 : integer] : TExcelSelection;
  published
    property OnConnect;
    property OnDisconnect;
    property ServerName;
    property UseFontCharset : Boolean;
  end;

  TExcelDataSet = class(TExcelDDE)
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
    procedure Fill;
  published
    property DataSet : TDataSet;
    property LeftOrigin : integer;
    property TopOrigin : integer;
    property Font : TFont;
    property TitleFont : TFont;
    property Silent : Boolean;
    property BeforeFill : TNotifyEvent;
    property AfterFill : TNotifyEvent;
  end;

  TExcelGrid = class(TExcelDDE)
  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
    procedure Fill;
  published
    property DBGrid : TDBGrid;
    property LeftOrigin : integer;
    property TopOrigin : integer;
    property Font : TFont;
    property TitleFont : TFont;
    property Silent : Boolean;
    property BeforeFill : TNotifyEvent;
    property AfterFill : TNotifyEvent;
    property UseGridFont : Boolean;
    property UseGridTitleFont : Boolean;
    property UseGridSelection : Boolean;
  end;

  TCustomExcelCell = class(TObject)
  public
    constructor Create(AExcelDDE : TExcelDDE);
    destructor Destroy; override;
    procedure Select; virtual; abstract;
    property Alignment  : TAlignment;
    property Row : integer;
    property Col : integer;
    property Font : TFont;
    property Border : TExcelBorder;
  end;

  TExcelCell = class(TCustomExcelCell)
  public
    procedure Select; override;
    property AsBoolean  : Boolean;
    property AsDateTime : TDateTime;
    property AsFloat    : Double;
    property AsInteger  : Longint;
    property AsString   : String;
    property AsVariant  : Variant;
  end;

  TExcelColumn = class(TCustomExcelCell)
  public
    procedure Select; override;
    property Width : integer;
  end;

  TExcelRow = class(TCustomExcelCell)
  public
    procedure Select; override;
    property Height : integer;
  end;

  TExcelSelection = class(TCustomExcelCell)
  public
    procedure Select; override;
    property Width : integer;
    property Height : integer;
    property RowEnd : integer;
    property ColEnd : integer;
  end;

  TExcelBorderLine = (xblNone, xblThin, xblMedium, xblDash, xblDot, xblThick,
                      xblDouble, xblVeryThin);
  TExcelBorder = class(TComponent)
  public
    procedure Assign(Source : TPersistent); override;
    procedure DisableControls;
    procedure EnableControls;
  published
    property Outline : TExcelBorderLine;
    property Left : TExcelBorderLine;
    property Right : TExcelBorderLine;
    property Top : TExcelBorderLine;
    property Bottom : TExcelBorderLine;
    property OnChange : TNotifyEvent;
  end;

procedure Register;

